#Declaration.mod

# Sets for the wells
set WELLS;

param WC {i in WELLS};
param GOR {i in WELLS};
param Qesp_min_at_ref {i in WELLS};
param Qesp_max_at_ref {i in WELLS};


# Set of break points for the well performances curves
set SFesp{i in WELLS} ordered by [0,Infinity];

# Parameters read from the well performance tables
param Qliq{i in WELLS, f in SFesp[i]}; #Liquid rate
param Wesp{i in WELLS, f in SFesp[i]}; #Power
param PumpEff{i in WELLS, f in SFesp[i]}; #Pump efficiency
param Psuc{i in WELLS, f in SFesp[i]}; #P suction
param Qesp{i in WELLS, f in SFesp[i]}; #Local flowrate

param qg_max;
param qw_max;
param qo_max;
param Wesp_max;
param ESP_max_freq;
param ESP_min_freq;
param p_b;

# Field Level
var var_qo_tot >= 0;
var var_qg_tot >= 0;
var var_qw_tot >= 0;

# pump efficiency variable
var var_pump_eff_tot >= 0;

# Well Level
var var_qliq{i in WELLS} >= 0;
var var_qo{i in WELLS} >= 0;
var var_Wesp{i in WELLS} >= 0;
var var_fesp{i in WELLS} >= 0;
var var_peff{i in WELLS} >= 0;
var var_p_suc{i in WELLS} >= 0;
var var_q_esp{i in WELLS} >= 0;
var var_q_pump_min{i in WELLS} >= 0;
var var_q_pump_max{i in WELLS} >= 0;




#On/Off binary variable
var var_on_off{i in WELLS} binary;

# SOS variables
var var_Lambda{i in WELLS, f in SFesp[i]} >= 0;

