model;



#--------------------------#
# OBJECTIVE :
# remove # from the objective line to set objective
# 3 possible objectives: max oil, min water, max pump efficiency
#--------------------------#

maximize oilProduction: var_qo_tot;
#minimize waterProduction: var_qw_tot;
#maximize pumpEfficiency: var_pump_eff_tot;

#--------------------------#
# CONSTRAINTS:
#--------------------------#
# DEFINING VARIABLES:
#--------------------------#

subject to definition_qliq{i in WELLS}:

	var_qliq[i] = sum{F in SFesp[i]} Qliq[i, F] * var_Lambda[i, F];


subject to definition_qw_tot: 

	var_qw_tot = sum {i in WELLS} var_qliq[i] * (WC[i]);

subject to definition_qo_tot: 

	var_qo_tot = sum {i in WELLS} var_qliq[i] * (1-WC[i]);


subject to definition_f_ESP{i in WELLS}:

	var_fesp[i] = sum{F in SFesp[i]} F * var_Lambda[i, F];


subject to definition_p_suc_ESP{i in WELLS}:

	var_p_suc[i] = sum{F in SFesp[i]} Psuc[i, F] * var_Lambda[i, F];

subject to definition_ESP_efficiency{i in WELLS}:

	var_peff[i] = sum{F in SFesp[i]} PumpEff[i, F] * var_Lambda[i, F];

subject to definition_max_efficiency:

	var_pump_eff_tot = sum{i in WELLS} var_peff[i];

subject to definition_qo{i in WELLS}:

	var_qo[i] = var_qliq[i] * (1-WC[i]);

#--------------------------#
#CONSTRAINTS ON LOCAL ESP RATE:
#--------------------------#
subject to definition_q_local_ESP{i in WELLS}:
	var_q_esp[i] = sum{F in SFesp[i]} Qesp[i, F] * var_Lambda[i, F];

subject to definition_q_min_esp_ESP{i in WELLS}:
	var_q_pump_min[i] = Qesp_min_at_ref[i] * (var_fesp[i] / 60);#F_reference = 60hz, should input as data later

subject to definition_q_max_esp_ESP{i in WELLS}:
	var_q_pump_max[i] = Qesp_max_at_ref[i] * (var_fesp[i] / 60);

subject to q_esp_min_flow{i in WELLS}:
	var_q_esp[i] >= var_q_pump_min[i];# * var_on_off[i];

subject to q_esp_max_flow{i in WELLS}:
	var_q_esp[i] <= var_q_pump_max[i];

#--------------------------#
#FIELD CONSTRAINTS:
#--------------------------#

subject to Max_Oil:
	var_qo_tot <= qo_max;

#subject to Min_Oil:
#	var_qo_tot >= qo_max;

subject to Max_Water:
	var_qw_tot <= qw_max;

subject to P_bubble_point {i in WELLS}:
	var_p_suc[i] >= p_b * 1.1 * var_on_off[i]; #1.1 = safety factor

subject to Max_ESP_freq {i in WELLS}:

	var_fesp[i] <= ESP_max_freq;#* var_on_off[i];

subject to Min_ESP_freq {i in WELLS}:

	var_fesp[i] >= ESP_min_freq * var_on_off[i];

#--------------------------#
#WELL INTERVENTION:
#--------------------------#

#subject to Intervene_Well_1{i in WELLS}:
#	i == "well_1" ==> var_on_off[i] = 0;

#subject to Intervene_Well_2{i in WELLS}:
#	i == "well_2" ==> var_on_off[i] = 0;

#subject to Intervene_Well_11{i in WELLS}:
#	i == "well_11" ==> var_on_off[i] = 0;

#subject to Intervene_Well_12{i in WELLS}:
#	i == "well_12" ==> var_on_off[i] = 0;


#--------------------------#
#SOS2 CONSTRAINTS:
#--------------------------#
subject to SOS2_sum_constraint{i in WELLS}: 

	sum{F in SFesp[i]} var_Lambda[i, F] = var_on_off[i]; #var_on_off[i]; #var_on_off[i]; #1;